@@ -48,7 +48,6 @@ License:
     See the License for the specific language governing permissions and
     limitations under the License.
 """
-
 import warnings
 from datetime import datetime
 from os import path
@@ -58,19 +57,21 @@ from time import sleep
 from colorama import Fore
 from dotenv import load_dotenv
 
-import PyFunceble.abstracts as abstracts
-import PyFunceble.config as cconfig
-import PyFunceble.converter as converter
-import PyFunceble.core as core
-import PyFunceble.database as database
-import PyFunceble.downloader as downloader
-import PyFunceble.engine as engine
-import PyFunceble.exceptions as exceptions
-import PyFunceble.extractor as extractor
-import PyFunceble.helpers as helpers
-import PyFunceble.lookup as lookup
-import PyFunceble.output as output
-import PyFunceble.status as status
+from PyFunceble import abstracts
+from PyFunceble import config as cconfig
+from PyFunceble import (
+    converter,
+    core,
+    database,
+    downloader,
+    engine,
+    exceptions,
+    extractor,
+    helpers,
+    lookup,
+    output,
+    status,
+)
 from PyFunceble.check import Check
 
 # We set our project name.
@@ -671,7 +672,9 @@ def is_url(subject):  # pragma: no cover
     return None
 
 
-def load_config(generate_directory_structure=False, custom=None):  # pragma: no cover
+def load_config(
+    generate_directory_structure=False, custom=None, sanity_check=False
+):  # pragma: no cover
     """
     Load the configuration.
 
@@ -682,6 +685,9 @@ def load_config(generate_directory_structure=False, custom=None):  # pragma: no
     :param dict custom:
         A dict with the configuration index (from .PyFunceble.yaml) to update.
 
+    :param bool sanity_check:
+        Tell us to run the safety check of the configuration.
+
     .. note::
         If :code:`config` is given, the given :code:`dict` overwrite
         the last value of the given indexes in the configuration.
@@ -705,6 +711,9 @@ def load_config(generate_directory_structure=False, custom=None):  # pragma: no
     else:
         LOADER.set_custom_config(custom)
 
+    if sanity_check:
+        cconfig.Preset().init_all()
+
     if generate_directory_structure:
         output.Constructor()
 
