@@ -49,8 +49,7 @@ License:
     See the License for the specific language governing permissions and
     limitations under the License.
 """
-
-import PyFunceble.helpers as helpers
+from PyFunceble import helpers
 
 
 class Package:
@@ -65,7 +64,7 @@ class Package:
     :type: str
     """
 
-    VERSION = "3.2.1. (Teal Blauwbok: Moth)"
+    VERSION = "3.3.2. (Teal Blauwbok: Tick)"
     """
     Sets the package version.
 
@@ -214,7 +213,9 @@ class Version:
         Checks if the local version is the development version.
         """
 
-        return "dev" in Package.VERSION
+        return cls.split_versions(Package.VERSION, return_non_digits=True)[
+            -1
+        ].startswith("dev")
 
     @classmethod
     def is_local_cloned(cls):  # pragma: no cover
