@@ -55,8 +55,11 @@ License:
 from os import cpu_count
 
 from colorama import Fore, Style
+from sqlalchemy.exc import OperationalError
 
 import PyFunceble
+from PyFunceble.engine.database.loader import credential
+from PyFunceble.engine.database.migrations import Alembic
 
 
 class Preset:  # pragma: no cover
@@ -64,6 +67,8 @@ class Preset:  # pragma: no cover
     Checks or update the global configuration based on some events.
     """
 
+    # pylint: disable=too-many-public-methods
+
     # List all index which can be superset.
     # In other words if an index which is listed here
     # is also listed into PyFunceble.INTERN["custom_config_loaded"],
@@ -96,7 +101,7 @@ class Preset:  # pragma: no cover
         self.syntax_test()
         self.reputation_data()
 
-        self.db_types()
+        self.upgrade_database()
 
     @classmethod
     def switch(
@@ -281,20 +286,14 @@ class Preset:  # pragma: no cover
     @classmethod
     def maximal_processes(cls):
         """
-        Ensures that the number of maximal processes is alway >= 1.
+        Ensures that the number of maximal processes is alway >= 2.
+        If not, we don't authorize the multiprocessing.
         """
 
-        if PyFunceble.CONFIGURATION.maximal_processes < 1:
-            PyFunceble.CONFIGURATION.maximal_processes = 1
-
-    @classmethod
-    def db_types(cls):
-        """
-        Ensure that the files are downloaded when the db types is not
-        the JSON one.
-        """
-
-        PyFunceble.downloader.DBType()
+        if PyFunceble.CONFIGURATION.multiprocess:
+            if PyFunceble.CONFIGURATION.maximal_processes < 2:
+                PyFunceble.CONFIGURATION.multiprocess = False
+                PyFunceble.CONFIGURATION.maximal_processes = 1
 
     @classmethod
     def multiprocess_merging_mode(cls):
@@ -303,14 +302,18 @@ class Preset:  # pragma: no cover
         """
 
         # pylint: disable=line-too-long
-        if not PyFunceble.CONFIGURATION.multiprocess_merging_mode or PyFunceble.CONFIGURATION.multiprocess_merging_mode.lower() not in [
-            "end",
-            "live",
-        ]:
+        if (
+            not PyFunceble.CONFIGURATION.multiprocess_merging_mode
+            or PyFunceble.CONFIGURATION.multiprocess_merging_mode.lower()
+            not in [
+                "end",
+                "live",
+            ]
+        ):
             PyFunceble.CONFIGURATION.multiprocess_merging_mode = "end"
 
         if PyFunceble.CONFIGURATION.db_type in ["mysql", "mariadb"]:
-            PyFunceble.CONFIGURATION.multiprocess_merging_mode = "end"
+            PyFunceble.CONFIGURATION.multiprocess_merging_mode = "live"
 
     def simple_domain(self):
         """
@@ -375,6 +378,7 @@ class Preset:  # pragma: no cover
         Prepares the global configuration for a test with multiple processes.
         """
 
+        self.maximal_processes()
         if PyFunceble.CONFIGURATION.multiprocess:
             if (
                 "multiprocess_warning_printed" not in PyFunceble.INTERN
@@ -398,7 +402,6 @@ class Preset:  # pragma: no cover
                     )
 
                 PyFunceble.INTERN["multiprocess_warning_printed"] = True
-            self.maximal_processes()
             self.multiprocess_merging_mode()
 
     @classmethod
@@ -468,3 +471,20 @@ class Preset:  # pragma: no cover
             PyFunceble.CONFIGURATION.cooldown_time = float(
                 PyFunceble.CONFIGURATION.cooldown_time
             )
+
+    @classmethod
+    def upgrade_database(cls):
+        """
+        Ensures that the database always have the latest state.
+        """
+
+        if (
+            PyFunceble.CONFIGURATION.db_type in ["mysql", "mariadb"]
+            and "migration_started" not in PyFunceble.CONFIGURATION
+        ):
+            try:
+                Alembic(credential.Credential()).upgrade()
+            except OperationalError:
+                pass
+
+            PyFunceble.CONFIGURATION["migration_started"] = True
