@@ -60,17 +60,22 @@ class UserAgent:
     """
 
     def __init__(self):
-        self.dumped = PyFunceble.helpers.Dict().from_json_file(
+        file_instance = PyFunceble.helpers.File(
             PyFunceble.CONFIG_DIRECTORY
             + PyFunceble.abstracts.Infrastructure.USER_AGENT_FILENAME
         )
 
+        if not file_instance.exists():
+            PyFunceble.downloader.UserAgents()
+
+        self.dumped = PyFunceble.helpers.Dict().from_json_file(file_instance.path)
+
     def get(self):
         """
         Provides the user agent to use.
         """
 
-        if not PyFunceble.CONFIGURATION.user_agent.custom:
+        if "custom" not in PyFunceble.CONFIGURATION.user_agent:
             if (
                 not PyFunceble.CONFIGURATION.user_agent.browser
                 or PyFunceble.CONFIGURATION.user_agent.browser not in self.dumped
